function gui(obj)
%gui generates a GUI to facilitate use of the SMLM class.
% This method generates a GUI which allows the user to load single-molecule
% localization microscopy data, set parameters through the
% SingleMoleculeFitting class, and generate results.

% Created by:
%   David J. Schodt (Lidke lab, 2020)


% Create a figure for the GUI.
DefaultFigurePosition = get(0, 'defaultFigurePosition');
FigureXYSize = [DefaultFigurePosition(3), 600];
GUIFigure = figure('MenuBar', 'none', ...
    'Name', 'SMLM Interface', 'NumberTitle', 'off', ...
    'Units', 'pixels' , ...
    'Position', [DefaultFigurePosition(1), 0, FigureXYSize]);

% Add some panels to help organize the GUI.
SMFPanel = uipanel(GUIFigure, 'Title', 'Fitting parameters', ...
    'Units', 'normalized', 'Position', [0, 0.3, 1, 0.7]);
ControlPanel = uipanel(GUIFigure, 'Title', 'Controls', ...
    'Units', 'normalized', 'Position', [0, 0, 1, 0.3]);

% Stick the SingleMoleculeFitting GUI inside of the SMFPanel.
obj.SMF.gui(SMFPanel)

% Add some controls to the ControlPanel.
% NOTE: To anyone adding to this, I'm trying to follow the convention
%       that the uicontrol handles have their type appended to the end
%       of the name, e.g., a pushbutton might be called 'TestFitPushbutton'
%       or 'TestFitButton'.  This is one of those things that is only
%       useful if all handles adhere to the convention!
TextSize = [0, 0, 0.2, 0.2];
EditSize = [0, 0, 0.1, 0.2];
ButtonSize = [0, 0, 0.2, 0.2];
ControlHandles.FullFitButton = uicontrol(ControlPanel, ...
    'Style', 'pushbutton', 'String', 'Full fit', ...
    'FontUnits', 'normalized', 'FontSize', 0.4, ...
    'Units', 'normalized', ...
    'Position', ButtonSize, 'callback', @runFullFit);
ControlHandles.TestFitButton = uicontrol(ControlPanel, ...
    'Style', 'pushbutton', 'String', 'Test fit', ...
    'FontUnits', 'normalized', 'FontSize', 0.4, ...
    'Units', 'normalized', ...
    'Position', ButtonSize + [0, ButtonSize(4), 0, 0], ...
    'callback', @runTestFit);
DatasetNumberTip = ...
    'Dataset number to be analyzed when you click ''Test fit''';
uicontrol(ControlPanel, ...
    'Style', 'text', 'String', 'Dataset number:', ...
    'FontUnits', 'normalized', 'FontSize', 0.4, ...
    'Units', 'normalized', ...
    'Position', TextSize + [0, 2*ButtonSize(4), 0, 0], ...
    'Tooltip', DatasetNumberTip);
ControlHandles.DatasetNumberEdit = uicontrol(ControlPanel, ...
    'Style', 'edit', 'String', '1', ...
    'FontUnits', 'normalized', 'FontSize', 0.4, ...
    'Units', 'normalized', ...
    'Position', EditSize + [TextSize(3), 2*ButtonSize(4), 0, 0], ...
    'Tooltip', DatasetNumberTip);


    function runTestFit(~,~)
        DatasetID=str2num(ControlHandles.DatasetNumberEdit.String);
        obj.CalledByGUI = true;
        obj.testFit(DatasetID);  
    end

    function runFullFit(~,~)
        obj.CalledByGUI = true;
        obj.fullAnalysis();  
    end


end
